bayespy.inference.vmp.transformations.RotateMultiple
====================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. autoclass:: RotateMultiple

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~RotateMultiple.__init__
      ~RotateMultiple.bound
      ~RotateMultiple.get_bound_terms
      ~RotateMultiple.nodes
      ~RotateMultiple.rotate
      ~RotateMultiple.setup
   
   

   
   
   